@@ -16,6 +16,7 @@
 from gi.repository import Atspi
 from pyatspi.enum import *
 from pyatspi.utils import *
+from pyatspi.interface import *
 
 
 __all__ = [
@@ -73,7 +74,7 @@ TEXT_CLIP_NONE = TEXT_CLIP_TYPE(0)
 
 #------------------------------------------------------------------------------
 
-class Text:
+class Text(interface):
         """
         The text interface should be implemented by objects which place
         textual information onscreen as character strings or glyphs.
@@ -100,9 +101,6 @@ class Text:
         and the set returned at a particular character offset via Text::getAttributeRun.
         """
 
-        def __init__(self, obj):
-                self.obj = obj
-
         def addSelection(self, index):
                 """
                 The result of calling addSelection on objects which already have
@@ -288,7 +286,7 @@ class Text:
                 but which were not explicitly specified by the content creator.
                 """
                 ret = Atspi.Text.get_default_attributes(self.obj)
-                return ';'.join([key + ':' + value for key, value in ret.iteritems()])
+                return ';'.join([key + ':' + value for key, value in ret.items()])
 
         def getNSelections(self):
                 """
